@@ -12,7 +12,7 @@ class TestKCD : public QObject
 
     public:
 
-    explicit TestKCD(QObject *parent = 0) :
+    explicit TestKCD(QObject *parent = nullptr) :
         QObject(parent),
         mKcd(new KCompactDisc(KCompactDisc::Asynchronous))
     {}
@@ -22,12 +22,12 @@ class TestKCD : public QObject
         mKcd->deleteLater();
     }
 
-    public slots:
+    public Q_SLOTS:
 
     void doTest()
     {
         qDebug() << "Starting test";
-        mKcd->setDevice(mKcd->defaultCdromDeviceName(), 50, true, "phonon");
+        mKcd->setDevice(mKcd->defaultCdromDeviceName(), 50, true, QStringLiteral("phonon"));
         qDebug() << "";
 
         qDebug() << "We have" << mKcd->audioSystems().size() << "audo systems available:";
